/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Represents the available cell selection aggregates.
 */
export interface SelectionAggregates {
    /**
     * The sum of all numbers in all selected cells bound to numeric fields.
     * Other selected cells that represent different data types do not affect the value.
     */
    sum?: number;
    /**
     * The smallest number in all selected cells bound to numeric fields.
     * Other selected cells that represent different data types do not affect the value.
     */
    min?: number;
    /**
     * The greatest number in all selected cells bound to numeric fields.
     * Other selected cells that represent different data types do not affect the value.
     */
    max?: number;
    /**
     * The average of all numbers in all selected cells bound to numeric fields.
     * Other selected cells that represent different data types do not affect the value.
     */
    average?: number;
    /**
     * The total number of all selected cells.
     */
    count?: number;
    /**
     * The total number of selected cells bound to a `true` boolean value.
     * Other selected cells that represent different data types do not affect the value.
     */
    isTrue?: number;
    /**
     * The total number of selected cells bound to a `false` boolean value.
     * Other selected cells that represent different data types do not affect the value
     */
    isFalse?: number;
    /**
     * The earliest date in all selected cells bound to `Date` fields.
     * Other selected cells that represent different data types do not affect the value.
     */
    earliest?: Date;
    /**
     * The latest date in all selected cells bound to `Date` fields.
     * Other selected cells that represent different data types do not affect the value.
     */
    latest?: Date;
}
/**
 * Represents the available selection aggregate calculations.
 * Use in combination with [cellAggregates]({% slug api_grid_selectablesettings %}) to determine which aggregates will be calculated.
 */
export type SelectionAggregate = 'sum' | 'min' | 'max' | 'average' | 'count' | 'earliest' | 'latest' | 'isTrue' | 'isFalse';
