/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter, ElementRef } from '@angular/core';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { ContextService } from '../common/provider.service';
import { ColumnMenuItemBase } from './column-menu-item-base';
import * as i0 from "@angular/core";
/**
 * Represents the column-menu item which combines the lock and sticky column functionalities.
 *
 * The component can be placed inside a [ColumnMenuTemplate]({% slug api_grid_columnmenutemplatedirective %}) directive.
 * To register the component as a known column menu item, set the [ColumnMenuService]({% slug api_grid_columnmenuservice %}) that is passed by
 * the template to the service input of the `kendo-grid-columnmenu-position` component. [See example](slug:columnmenu_grid#toc-set-column-position-item).
 *
 * @example
 * ```html
 * <kendo-grid [data]="data" [columnMenu]="true" ...>
 *   <ng-template kendoGridColumnMenuTemplate let-service="service" let-column="column">
 *     <kendo-grid-columnmenu-position [service]="service" [showLock]="true" [showStick]="true">
 *     </kendo-grid-columnmenu-position>
 *   </ng-template>
 * </kendo-grid>
 * ```
 */
export declare class ColumnMenuPositionComponent extends ColumnMenuItemBase {
    ctx: ContextService;
    private hostElement;
    /**
     * Fires when the content is expanded.
     */
    expand: EventEmitter<any>;
    /**
     * Fires when the content is collapsed.
     */
    collapse: EventEmitter<any>;
    /**
     * Specifies if the content is expanded.
     * @default false
     */
    expanded: boolean;
    /**
     * Specifies if the lock column item is displayed.
     */
    showLock: boolean;
    /**
     * Specifies if the stick column item is displayed.
     */
    showStick: boolean;
    /**
     * @hidden
     */
    actionsClass: string;
    /**
     * @hidden
     */
    set isLast(value: boolean);
    /**
     * @hidden
     */
    get isLast(): boolean;
    setColumnPositionIcon: SVGIcon;
    private _isLast;
    constructor(ctx: ContextService, hostElement: ElementRef);
    /**
     * @hidden
     */
    onTab(e: Event, isLastItem: boolean): void;
    /**
     * @hidden
     */
    onCollapse(): void;
    /**
     * @hidden
     */
    onExpand(): void;
    private getLastFocusableItem;
    static ɵfac: i0.ɵɵFactoryDeclaration<ColumnMenuPositionComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ColumnMenuPositionComponent, "kendo-grid-columnmenu-position", never, { "expanded": { "alias": "expanded"; "required": false; }; "showLock": { "alias": "showLock"; "required": false; }; "showStick": { "alias": "showStick"; "required": false; }; "isLast": { "alias": "isLast"; "required": false; }; }, { "expand": "expand"; "collapse": "collapse"; }, never, never, true, never>;
}
