/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef } from '@angular/core';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { ColumnInfoService } from '../common/column-info.service';
import { ContextService } from '../common/provider.service';
import { ColumnMenuItemBase } from './column-menu-item-base';
import * as i0 from "@angular/core";
/**
 * Represents the column-menu item that sticks or unsticks columns in the Grid.
 * [See example](slug:columnmenu_grid#toc-stick-and-unstick-items).
 *
 * The component can be placed inside a [ColumnMenuTemplate]({% slug api_grid_columnmenutemplatedirective %}) directive.
 * To register the component as a known column menu item, set the [ColumnMenuService]({% slug api_grid_columnmenuservice %}) that is passed by
 * the template to the service input of the `kendo-grid-columnmenu-lock` component. [See example](slug:columnmenu_grid#toc-customizing-the-content).
 *
 * @example
 * ```html
 * <kendo-grid [data]="data" [columnMenu]="true">
 *   <ng-template kendoGridColumnMenuTemplate let-service="service">
 *      <kendo-grid-columnmenu-stick [service]="service">
 *      </kendo-grid-columnmenu-stick>
 *   </ng-template>
 * </kendo-grid>
 *
 * ```
 */
export declare class ColumnMenuStickComponent extends ColumnMenuItemBase {
    private ctx;
    private columnInfoService;
    private changeDetector;
    stickIcon: SVGIcon;
    unstickIcon: SVGIcon;
    constructor(ctx: ContextService, columnInfoService: ColumnInfoService, changeDetector: ChangeDetectorRef);
    get text(): string;
    get icon(): string;
    get svgIcon(): SVGIcon;
    get disabled(): boolean;
    /**
     * @hidden
     */
    toggleColumn(): void;
    private toggleHierarchy;
    private get sticky();
    static ɵfac: i0.ɵɵFactoryDeclaration<ColumnMenuStickComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ColumnMenuStickComponent, "kendo-grid-columnmenu-stick", never, {}, {}, never, never, true, never>;
}
