/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { QueryList } from '@angular/core';
import { IdService } from '../common/id.service';
import { ColumnBase } from './column-base';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare function isColumnGroupComponent(column: any): column is ColumnGroupComponent;
/**
 * Represents the column group header of the Grid
 * ([more information and examples](slug:multicolumnheaders_columns_grid)).
 *
 * @example
 * ```html
 * <kendo-grid [data]="gridData">
 *   <kendo-grid-column-group title="Product Info">
 *     <kendo-grid-column field="ProductID"></kendo-grid-column>
 *     <kendo-grid-column field="ProductName"></kendo-grid-column>
 *   </kendo-grid-column-group>
 *   <kendo-grid-column field="UnitPrice"></kendo-grid-column>
 * </kendo-grid>
 * ```
 */
export declare class ColumnGroupComponent extends ColumnBase {
    parent?: ColumnBase;
    /**
     * @hidden
     */
    includeInChooser: boolean;
    /**
     * @hidden
     */
    isColumnGroup: boolean;
    /**
     * @hidden
     */
    minResizableWidth: number;
    /**
     * @hidden
     */
    maxResizableWidth: number;
    /**
     * @hidden
     */
    children: QueryList<ColumnBase>;
    constructor(parent?: ColumnBase, idService?: IdService);
    /**
     * @hidden
     */
    rowspan(): number;
    /**
     * @hidden
     */
    get colspan(): number;
    /**
     * @hidden
     */
    get leafIndex(): number;
    get childrenArray(): any[];
    get hasChildren(): boolean;
    private get firstChild();
    static ɵfac: i0.ɵɵFactoryDeclaration<ColumnGroupComponent, [{ optional: true; host: true; skipSelf: true; }, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ColumnGroupComponent, "kendo-grid-column-group", never, {}, {}, ["children"], never, true, never>;
}
