/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { OnInit, OnDestroy } from '@angular/core';
import { GridComponent } from '../grid.component';
import { EditService } from './edit-service.interface';
import { Subscription } from 'rxjs';
import { LocalDataChangesService } from '../editing/local-data-changes.service';
import { RemoveConfirmationCallback } from '../common/remove-confirmation';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare abstract class EditingDirectiveBase implements OnInit, OnDestroy {
    protected grid: GridComponent;
    protected localDataChangesService: LocalDataChangesService;
    /**
     * The edit service that will handle the operations.
     */
    set editService(value: EditService);
    get editService(): EditService;
    /**
     * A function that is called to confirm if the `dataItem` will be removed.
     */
    removeConfirmation: RemoveConfirmationCallback;
    protected subscriptions: Subscription;
    protected defaultEditService: EditService;
    protected userEditService: EditService;
    protected abstract createModel(args: any): any;
    protected abstract saveModel(args: any): any;
    constructor(grid: GridComponent, localDataChangesService: LocalDataChangesService);
    /**
     * @hidden
     */
    ngOnInit(): void;
    /**
     * @hidden
     */
    ngOnDestroy(): void;
    protected createDefaultService(): EditService;
    protected addHandler(): void;
    protected saveHandler(args: any): void;
    protected cancelHandler({ rowIndex }: any): void;
    protected removeHandler({ dataItem }: any): void;
    protected onStateChange(): void;
    protected closeEditor(rowIndex?: number): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<EditingDirectiveBase, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<EditingDirectiveBase, "[kendoGridEditingDirectiveBase]", never, { "editService": { "alias": "editService"; "required": false; }; "removeConfirmation": { "alias": "removeConfirmation"; "required": false; }; }, {}, never, never, false, never>;
}
