/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PreventableEvent } from '../common/preventable-event';
/**
 * Arguments for the `columnReorder` event.
 */
export class ColumnReorderEvent extends PreventableEvent {
    /**
     * The reordered column.
     */
    column;
    /**
     * The new index of the column.
     * Relative to the collection of columns.
     */
    newIndex;
    /**
     * The original index of the column before reordering.
     * Relative to the collection of columns.
     */
    oldIndex;
    /**
     * @hidden
     */
    constructor({ column, newIndex, oldIndex }) {
        super();
        this.column = column;
        this.newIndex = newIndex;
        this.oldIndex = oldIndex;
    }
}
