/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NgModule } from '@angular/core';
import { ResizeBatchService } from '@progress/kendo-angular-common';
import { CalendarDOMService, CenturyViewService, DecadeViewService, MonthViewService, YearViewService, NavigationService } from '@progress/kendo-angular-dateinputs';
import { DialogContainerService, DialogService, WindowService, WindowContainerService } from '@progress/kendo-angular-dialog';
import { IconsService } from '@progress/kendo-angular-icons';
import { PopupService } from '@progress/kendo-angular-popup';
import { KENDO_GRID_BODY_EXPORTS, KENDO_GRID_COLUMN_MENU_DECLARATIONS, KENDO_GRID_DECLARATIONS, KENDO_GRID_EXPORTS, KENDO_GRID_FILTER_MENU, KENDO_GRID_FILTER_ROW, KENDO_GRID_FOOTER_EXPORTS, KENDO_GRID_GROUP_EXPORTS, KENDO_GRID_HEADER_EXPORTS, KENDO_GRID_SHARED } from './directives';
import { TableDirective } from './column-resizing/table.directive';
import { KENDO_PAGER } from '@progress/kendo-angular-pager';
import { KENDO_TOOLBAR } from '@progress/kendo-angular-toolbar';
import * as i0 from "@angular/core";
import * as i1 from "./grouping/group-header-template.directive";
import * as i2 from "./grouping/group-header-column-template.directive";
import * as i3 from "./grouping/group-footer-template.directive";
import * as i4 from "./grouping/group-header.component";
import * as i5 from "./grouping/group-panel.component";
import * as i6 from "./columns/column.component";
import * as i7 from "./columns/column-group.component";
import * as i8 from "./navigation/logical-cell.directive";
import * as i9 from "./navigation/logical-row.directive";
import * as i10 from "./navigation/focusable.directive";
import * as i11 from "./rendering/footer/footer-template.directive";
import * as i12 from "./rendering/common/col-group.component";
import * as i13 from "./layout/resizable.directive";
import * as i14 from "@progress/kendo-angular-common";
import * as i15 from "./rendering/common/field-accessor.pipe";
import * as i16 from "./rendering/details/detail-template.directive";
import * as i17 from "./columns/span-column.component";
import * as i18 from "./rendering/common/loading.component";
import * as i19 from "./rendering/grid-table.directive";
import * as i20 from "./columns/command-column.component";
import * as i21 from "./columns/checkbox-column.component";
import * as i22 from "./selection/selection-checkbox.directive";
import * as i23 from "./rendering/cell-template.directive";
import * as i24 from "./editing/edit-template.directive";
import * as i25 from "./rendering/table-body.component";
import * as i26 from "./rendering/no-records-template.directive";
import * as i27 from "./rendering/cell.component";
import * as i28 from "./editing/edit-command.directive";
import * as i29 from "./editing/cancel-command.directive";
import * as i30 from "./editing/save-command.directive";
import * as i31 from "./editing/remove-command.directive";
import * as i32 from "./editing/add-command.directive";
import * as i33 from "./editing/add-command-tool.directive";
import * as i34 from "./rendering/cell-loading.template.directive";
import * as i35 from "./rendering/loading-template.directive";
import * as i36 from "./columns/reorder-column.component";
import * as i37 from "./rendering/header/header.component";
import * as i38 from "./rendering/header/header-template.directive";
import * as i39 from "./column-resizing/column-handle.directive";
import * as i40 from "./selection/selectall-checkbox.directive";
import * as i41 from "./rendering/footer/footer.component";
import * as i42 from "@progress/kendo-angular-pager";
import * as i43 from "@progress/kendo-angular-toolbar";
import * as i44 from "./filtering/filter-row.component";
import * as i45 from "./filtering/cell/filter-cell.component";
import * as i46 from "./filtering/cell/filter-cell-template.directive";
import * as i47 from "./filtering/cell/string-filter-cell.component";
import * as i48 from "./filtering/cell/numeric-filter-cell.component";
import * as i49 from "./filtering/cell/autocomplete-filter-cell.component";
import * as i50 from "./filtering/cell/boolean-filter-cell.component";
import * as i51 from "./filtering/cell/filter-cell-host.directive";
import * as i52 from "./filtering/cell/filter-cell-wrapper.component";
import * as i53 from "./filtering/cell/date-filter-cell.component";
import * as i54 from "./filtering/cell/filter-cell-operators.component";
import * as i55 from "./filtering/operators/contains-filter-operator.component";
import * as i56 from "./filtering/operators/not-contains-filter-operator.component";
import * as i57 from "./filtering/operators/ends-with-filter-operator.component";
import * as i58 from "./filtering/operators/eq-filter-operator.component";
import * as i59 from "./filtering/operators/is-empty-filter-operator.component";
import * as i60 from "./filtering/operators/is-not-empty-filter-operator.component";
import * as i61 from "./filtering/operators/is-not-null-filter-operator.component";
import * as i62 from "./filtering/operators/isnull-filter-operator.component";
import * as i63 from "./filtering/operators/neq-filter-operator.component";
import * as i64 from "./filtering/operators/starts-with-filter-operator.component";
import * as i65 from "./filtering/operators/gt-filter-operator.component";
import * as i66 from "./filtering/operators/gte-filter-operator.component";
import * as i67 from "./filtering/operators/lt-filter-operator.component";
import * as i68 from "./filtering/operators/lte-filter-operator.component";
import * as i69 from "./filtering/operators/after-filter-operator.component";
import * as i70 from "./filtering/operators/after-eq-filter-operator.component";
import * as i71 from "./filtering/operators/before-eq-filter-operator.component";
import * as i72 from "./filtering/operators/before-filter-operator.component";
import * as i73 from "./filtering/filter-input.directive";
import * as i74 from "./filtering/menu/filter-menu.component";
import * as i75 from "./filtering/menu/filter-menu-container.component";
import * as i76 from "./filtering/menu/filter-menu-input-wrapper.component";
import * as i77 from "./filtering/menu/string-filter-menu-input.component";
import * as i78 from "./filtering/menu/string-filter-menu.component";
import * as i79 from "./filtering/menu/filter-menu-template.directive";
import * as i80 from "./filtering/menu/numeric-filter-menu.component";
import * as i81 from "./filtering/menu/numeric-filter-menu-input.component";
import * as i82 from "./filtering/menu/date-filter-menu-input.component";
import * as i83 from "./filtering/menu/date-filter-menu.component";
import * as i84 from "./filtering/menu/filter-menu-host.directive";
import * as i85 from "./filtering/menu/boolean-filter-menu.component";
import * as i86 from "./filtering/menu/filter-menu-dropdownlist.directive";
import * as i87 from "./filtering/menu/filter-radio-button.directive";
import * as i88 from "./column-menu/column-chooser-item-checked.directive";
import * as i89 from "./column-menu/column-list.component";
import * as i90 from "./column-menu/column-chooser.component";
import * as i91 from "./column-menu/column-menu-chooser.component";
import * as i92 from "./column-menu/column-menu-filter.component";
import * as i93 from "./column-menu/column-menu-item.component";
import * as i94 from "./column-menu/column-menu-item-content-template.directive";
import * as i95 from "./column-menu/column-menu-sort.component";
import * as i96 from "./column-menu/column-menu.component";
import * as i97 from "./column-menu/column-menu-lock.component";
import * as i98 from "./column-menu/column-menu-template.directive";
import * as i99 from "./column-menu/column-menu-container.component";
import * as i100 from "./column-menu/column-menu-item.directive";
import * as i101 from "./column-menu/column-menu-stick.component";
import * as i102 from "./column-menu/column-menu-position.component";
import * as i103 from "./column-menu/column-menu-autosize.component";
import * as i104 from "./column-menu/column-menu-autosize-all.component";
import * as i105 from "./grid.component";
import * as i106 from "./rendering/list.component";
import * as i107 from "./rendering/toolbar/toolbar.component";
import * as i108 from "./localization/localized-messages.directive";
import * as i109 from "./localization/custom-messages.component";
import * as i110 from "./databinding.directive";
import * as i111 from "./rendering/toolbar/toolbar-template.directive";
import * as i112 from "./selection/selection.directive";
import * as i113 from "./editing-directives/template-editing.directive";
import * as i114 from "./editing-directives/reactive-editing.directive";
import * as i115 from "./editing-directives/in-cell-editing.directive";
import * as i116 from "./rendering/details-expand.directive";
import * as i117 from "./rendering/groups-expand.directive";
import * as i118 from "./grouping/group-scroll-binding.directive";
import * as i119 from "./selection/marquee.directive";
import * as i120 from "./rendering/common/spacer.component";
import * as i121 from "./rendering/toolbar/toolbar-focusable.directive";
import * as i122 from "./aggregates/status-bar.component";
import * as i123 from "./aggregates/status-bar-template.directive";
import * as i124 from "./common/clipboard.directive";
// IMPORTANT: NgModule export kept for backwards compatibility
/**
 * Represents the [NgModule](link:site.data.urls.angular['ngmoduleapi'])
 * definition for the Grid component.
 *
 * @example
 *
 * ```ts
 * import { NgModule } from '@angular/core';
 * import { GridModule } from '@progress/kendo-angular-grid';
 * import { BrowserModule } from "@angular/platform-browser";
 * import { AppComponent } from './app.component';
 *
 * @NgModule({
 *     declarations: [AppComponent],
 *     imports:      [BrowserModule, GridModule],
 *     bootstrap:    [AppComponent]
 * })
 * export class AppModule {}
 *
 * ```
 */
export class GridModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: GridModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: GridModule, imports: [i1.GroupHeaderTemplateDirective, i2.GroupHeaderColumnTemplateDirective, i3.GroupFooterTemplateDirective, i4.GroupHeaderComponent, i5.GroupPanelComponent, i6.ColumnComponent, i7.ColumnGroupComponent, i8.LogicalCellDirective, i9.LogicalRowDirective, i10.FocusableDirective, i11.FooterTemplateDirective, i12.ColGroupComponent, i13.ResizableContainerDirective, i14.TemplateContextDirective, i15.FieldAccessorPipe, i16.DetailTemplateDirective, i17.SpanColumnComponent, i18.LoadingComponent, i19.GridTableDirective, i20.CommandColumnComponent, i21.CheckboxColumnComponent, i22.SelectionCheckboxDirective, i23.CellTemplateDirective, i24.EditTemplateDirective, i25.TableBodyComponent, i26.NoRecordsTemplateDirective, i27.CellComponent, i28.EditCommandDirective, i29.CancelCommandDirective, i30.SaveCommandDirective, i31.RemoveCommandDirective, i32.AddCommandDirective, i33.AddCommandToolbarDirective, i34.CellLoadingTemplateDirective, i35.LoadingTemplateDirective, i36.RowReorderColumnComponent, i37.HeaderComponent, i38.HeaderTemplateDirective, i39.ColumnHandleDirective, i40.SelectAllCheckboxDirective, i41.FooterComponent, i42.CustomMessagesComponent, i42.PagerFocusableDirective, i42.PagerInfoComponent, i42.PagerInputComponent, i42.PagerNextButtonsComponent, i42.PagerNumericButtonsComponent, i42.PagerPageSizesComponent, i42.PagerPrevButtonsComponent, i42.PagerTemplateDirective, i42.PagerComponent, i42.PagerSpacerComponent, i43.ToolBarComponent, i43.ToolbarCustomMessagesComponent, i43.ToolBarButtonComponent, i43.ToolBarButtonGroupComponent, i43.ToolBarDropDownButtonComponent, i43.ToolBarSeparatorComponent, i43.ToolBarSpacerComponent, i43.ToolBarSplitButtonComponent, i43.ToolBarToolComponent, i44.FilterRowComponent, i45.FilterCellComponent, i46.FilterCellTemplateDirective, i47.StringFilterCellComponent, i48.NumericFilterCellComponent, i49.AutoCompleteFilterCellComponent, i50.BooleanFilterCellComponent, i51.FilterCellHostDirective, i52.FilterCellWrapperComponent, i53.DateFilterCellComponent, i6.ColumnComponent, i7.ColumnGroupComponent, i8.LogicalCellDirective, i9.LogicalRowDirective, i10.FocusableDirective, i11.FooterTemplateDirective, i12.ColGroupComponent, i13.ResizableContainerDirective, i14.TemplateContextDirective, i15.FieldAccessorPipe, i16.DetailTemplateDirective, i17.SpanColumnComponent, i18.LoadingComponent, i19.GridTableDirective, i54.FilterCellOperatorsComponent, i55.ContainsFilterOperatorComponent, i56.DoesNotContainFilterOperatorComponent, i57.EndsWithFilterOperatorComponent, i58.EqualFilterOperatorComponent, i59.IsEmptyFilterOperatorComponent, i60.IsNotEmptyFilterOperatorComponent, i61.IsNotNullFilterOperatorComponent, i62.IsNullFilterOperatorComponent, i63.NotEqualFilterOperatorComponent, i64.StartsWithFilterOperatorComponent, i65.GreaterFilterOperatorComponent, i66.GreaterOrEqualToFilterOperatorComponent, i67.LessFilterOperatorComponent, i68.LessOrEqualToFilterOperatorComponent, i69.AfterFilterOperatorComponent, i70.AfterEqFilterOperatorComponent, i71.BeforeEqFilterOperatorComponent, i72.BeforeFilterOperatorComponent, i73.FilterInputDirective, i6.ColumnComponent, i7.ColumnGroupComponent, i8.LogicalCellDirective, i9.LogicalRowDirective, i10.FocusableDirective, i11.FooterTemplateDirective, i12.ColGroupComponent, i13.ResizableContainerDirective, i14.TemplateContextDirective, i15.FieldAccessorPipe, i16.DetailTemplateDirective, i17.SpanColumnComponent, i18.LoadingComponent, i19.GridTableDirective, i54.FilterCellOperatorsComponent, i55.ContainsFilterOperatorComponent, i56.DoesNotContainFilterOperatorComponent, i57.EndsWithFilterOperatorComponent, i58.EqualFilterOperatorComponent, i59.IsEmptyFilterOperatorComponent, i60.IsNotEmptyFilterOperatorComponent, i61.IsNotNullFilterOperatorComponent, i62.IsNullFilterOperatorComponent, i63.NotEqualFilterOperatorComponent, i64.StartsWithFilterOperatorComponent, i65.GreaterFilterOperatorComponent, i66.GreaterOrEqualToFilterOperatorComponent, i67.LessFilterOperatorComponent, i68.LessOrEqualToFilterOperatorComponent, i69.AfterFilterOperatorComponent, i70.AfterEqFilterOperatorComponent, i71.BeforeEqFilterOperatorComponent, i72.BeforeFilterOperatorComponent, i73.FilterInputDirective, i74.FilterMenuComponent, i75.FilterMenuContainerComponent, i76.FilterMenuInputWrapperComponent, i77.StringFilterMenuInputComponent, i78.StringFilterMenuComponent, i79.FilterMenuTemplateDirective, i80.NumericFilterMenuComponent, i81.NumericFilterMenuInputComponent, i82.DateFilterMenuInputComponent, i83.DateFilterMenuComponent, i84.FilterMenuHostDirective, i85.BooleanFilterMenuComponent, i86.FilterMenuDropDownListDirective, i87.BooleanFilterRadioButtonDirective, i88.ColumnMenuChooserItemCheckedDirective, i89.ColumnListComponent, i90.ColumnChooserComponent, i91.ColumnMenuChooserComponent, i92.ColumnMenuFilterComponent, i93.ColumnMenuItemComponent, i94.ColumnMenuItemContentTemplateDirective, i95.ColumnMenuSortComponent, i96.ColumnMenuComponent, i97.ColumnMenuLockComponent, i98.ColumnMenuTemplateDirective, i99.ColumnMenuContainerComponent, i100.ColumnMenuItemDirective, i101.ColumnMenuStickComponent, i102.ColumnMenuPositionComponent, i103.ColumnMenuAutoSizeColumnComponent, i104.ColumnMenuAutoSizeAllColumnsComponent, i105.GridComponent, i106.ListComponent, i107.ToolbarComponent, i108.LocalizedMessagesDirective, i109.CustomMessagesComponent, i110.DataBindingDirective, i111.ToolbarTemplateDirective, i112.SelectionDirective, i113.TemplateEditingDirective, i114.ReactiveEditingDirective, i115.InCellEditingDirective, i116.ExpandDetailsDirective, i117.ExpandGroupDirective, i118.GroupBindingDirective, i119.GridMarqueeDirective, i120.GridSpacerComponent, i121.GridToolbarFocusableDirective, i122.StatusBarComponent, i123.StatusBarTemplateDirective, i124.GridClipboardDirective, i43.ToolBarComponent, i43.ToolbarCustomMessagesComponent, i43.ToolBarButtonComponent, i43.ToolBarButtonGroupComponent, i43.ToolBarDropDownButtonComponent, i43.ToolBarSeparatorComponent, i43.ToolBarSpacerComponent, i43.ToolBarSplitButtonComponent, i43.ToolBarToolComponent, TableDirective], exports: [i105.GridComponent, i111.ToolbarTemplateDirective, i107.ToolbarComponent, i120.GridSpacerComponent, i123.StatusBarTemplateDirective, i110.DataBindingDirective, i112.SelectionDirective, i109.CustomMessagesComponent, i118.GroupBindingDirective, i113.TemplateEditingDirective, i114.ReactiveEditingDirective, i115.InCellEditingDirective, i116.ExpandDetailsDirective, i117.ExpandGroupDirective, i121.GridToolbarFocusableDirective, i1.GroupHeaderTemplateDirective, i2.GroupHeaderColumnTemplateDirective, i3.GroupFooterTemplateDirective, i4.GroupHeaderComponent, i5.GroupPanelComponent, i6.ColumnComponent, i7.ColumnGroupComponent, i8.LogicalCellDirective, i9.LogicalRowDirective, i10.FocusableDirective, i11.FooterTemplateDirective, i12.ColGroupComponent, i13.ResizableContainerDirective, i14.TemplateContextDirective, i15.FieldAccessorPipe, i16.DetailTemplateDirective, i17.SpanColumnComponent, i18.LoadingComponent, i19.GridTableDirective, i20.CommandColumnComponent, i21.CheckboxColumnComponent, i22.SelectionCheckboxDirective, i23.CellTemplateDirective, i24.EditTemplateDirective, i25.TableBodyComponent, i26.NoRecordsTemplateDirective, i27.CellComponent, i28.EditCommandDirective, i29.CancelCommandDirective, i30.SaveCommandDirective, i31.RemoveCommandDirective, i32.AddCommandDirective, i33.AddCommandToolbarDirective, i34.CellLoadingTemplateDirective, i35.LoadingTemplateDirective, i36.RowReorderColumnComponent, i37.HeaderComponent, i38.HeaderTemplateDirective, i39.ColumnHandleDirective, i40.SelectAllCheckboxDirective, i44.FilterRowComponent, i45.FilterCellComponent, i46.FilterCellTemplateDirective, i47.StringFilterCellComponent, i48.NumericFilterCellComponent, i49.AutoCompleteFilterCellComponent, i50.BooleanFilterCellComponent, i51.FilterCellHostDirective, i52.FilterCellWrapperComponent, i53.DateFilterCellComponent, i54.FilterCellOperatorsComponent, i55.ContainsFilterOperatorComponent, i56.DoesNotContainFilterOperatorComponent, i57.EndsWithFilterOperatorComponent, i58.EqualFilterOperatorComponent, i59.IsEmptyFilterOperatorComponent, i60.IsNotEmptyFilterOperatorComponent, i61.IsNotNullFilterOperatorComponent, i62.IsNullFilterOperatorComponent, i63.NotEqualFilterOperatorComponent, i64.StartsWithFilterOperatorComponent, i65.GreaterFilterOperatorComponent, i66.GreaterOrEqualToFilterOperatorComponent, i67.LessFilterOperatorComponent, i68.LessOrEqualToFilterOperatorComponent, i69.AfterFilterOperatorComponent, i70.AfterEqFilterOperatorComponent, i71.BeforeEqFilterOperatorComponent, i72.BeforeFilterOperatorComponent, i74.FilterMenuComponent, i75.FilterMenuContainerComponent, i76.FilterMenuInputWrapperComponent, i77.StringFilterMenuInputComponent, i78.StringFilterMenuComponent, i79.FilterMenuTemplateDirective, i80.NumericFilterMenuComponent, i81.NumericFilterMenuInputComponent, i82.DateFilterMenuInputComponent, i83.DateFilterMenuComponent, i84.FilterMenuHostDirective, i85.BooleanFilterMenuComponent, i86.FilterMenuDropDownListDirective, i87.BooleanFilterRadioButtonDirective, i90.ColumnChooserComponent, i92.ColumnMenuFilterComponent, i93.ColumnMenuItemComponent, i94.ColumnMenuItemContentTemplateDirective, i95.ColumnMenuSortComponent, i97.ColumnMenuLockComponent, i101.ColumnMenuStickComponent, i102.ColumnMenuPositionComponent, i91.ColumnMenuChooserComponent, i98.ColumnMenuTemplateDirective, i99.ColumnMenuContainerComponent, i100.ColumnMenuItemDirective, i96.ColumnMenuComponent, i103.ColumnMenuAutoSizeColumnComponent, i104.ColumnMenuAutoSizeAllColumnsComponent, i124.GridClipboardDirective, i43.ToolBarComponent, i43.ToolbarCustomMessagesComponent, i43.ToolBarButtonComponent, i43.ToolBarButtonGroupComponent, i43.ToolBarDropDownButtonComponent, i43.ToolBarSeparatorComponent, i43.ToolBarSpacerComponent, i43.ToolBarSplitButtonComponent, i43.ToolBarToolComponent, i42.CustomMessagesComponent, i42.PagerFocusableDirective, i42.PagerInfoComponent, i42.PagerInputComponent, i42.PagerNextButtonsComponent, i42.PagerNumericButtonsComponent, i42.PagerPageSizesComponent, i42.PagerPrevButtonsComponent, i42.PagerTemplateDirective, i42.PagerComponent, i42.PagerSpacerComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: GridModule, providers: [
            PopupService,
            ResizeBatchService,
            IconsService,
            DialogContainerService,
            DialogService,
            WindowService,
            WindowContainerService,
            CalendarDOMService,
            CenturyViewService,
            DecadeViewService,
            MonthViewService,
            YearViewService,
            NavigationService
        ], imports: [i4.GroupHeaderComponent, i5.GroupPanelComponent, i25.TableBodyComponent, i27.CellComponent, i28.EditCommandDirective, i29.CancelCommandDirective, i30.SaveCommandDirective, i31.RemoveCommandDirective, i32.AddCommandDirective, i37.HeaderComponent, i42.CustomMessagesComponent, i42.PagerInfoComponent, i42.PagerInputComponent, i42.PagerNextButtonsComponent, i42.PagerNumericButtonsComponent, i42.PagerPageSizesComponent, i42.PagerPrevButtonsComponent, i42.PagerComponent, i42.PagerSpacerComponent, i43.ToolBarComponent, i43.ToolbarCustomMessagesComponent, i43.ToolBarButtonComponent, i43.ToolBarButtonGroupComponent, i43.ToolBarDropDownButtonComponent, i43.ToolBarSeparatorComponent, i43.ToolBarSpacerComponent, i43.ToolBarSplitButtonComponent, i47.StringFilterCellComponent, i48.NumericFilterCellComponent, i49.AutoCompleteFilterCellComponent, i50.BooleanFilterCellComponent, i52.FilterCellWrapperComponent, i53.DateFilterCellComponent, i54.FilterCellOperatorsComponent, i54.FilterCellOperatorsComponent, i74.FilterMenuComponent, i75.FilterMenuContainerComponent, i76.FilterMenuInputWrapperComponent, i77.StringFilterMenuInputComponent, i78.StringFilterMenuComponent, i80.NumericFilterMenuComponent, i81.NumericFilterMenuInputComponent, i82.DateFilterMenuInputComponent, i83.DateFilterMenuComponent, i85.BooleanFilterMenuComponent, i89.ColumnListComponent, i90.ColumnChooserComponent, i91.ColumnMenuChooserComponent, i92.ColumnMenuFilterComponent, i93.ColumnMenuItemComponent, i95.ColumnMenuSortComponent, i96.ColumnMenuComponent, i97.ColumnMenuLockComponent, i101.ColumnMenuStickComponent, i102.ColumnMenuPositionComponent, i103.ColumnMenuAutoSizeColumnComponent, i104.ColumnMenuAutoSizeAllColumnsComponent, i105.GridComponent, i106.ListComponent, i43.ToolBarComponent, i43.ToolbarCustomMessagesComponent, i43.ToolBarButtonComponent, i43.ToolBarButtonGroupComponent, i43.ToolBarDropDownButtonComponent, i43.ToolBarSeparatorComponent, i43.ToolBarSpacerComponent, i43.ToolBarSplitButtonComponent] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: GridModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [...KENDO_GRID_EXPORTS, ...KENDO_TOOLBAR, ...KENDO_PAGER],
                    imports: [
                        ...KENDO_GRID_GROUP_EXPORTS,
                        ...KENDO_GRID_SHARED,
                        ...KENDO_GRID_BODY_EXPORTS,
                        ...KENDO_GRID_HEADER_EXPORTS,
                        ...KENDO_GRID_FOOTER_EXPORTS,
                        ...KENDO_PAGER,
                        ...KENDO_TOOLBAR,
                        ...KENDO_GRID_FILTER_ROW,
                        ...KENDO_GRID_FILTER_MENU,
                        ...KENDO_GRID_COLUMN_MENU_DECLARATIONS,
                        ...KENDO_GRID_DECLARATIONS,
                        ...KENDO_TOOLBAR,
                        TableDirective
                    ],
                    providers: [
                        PopupService,
                        ResizeBatchService,
                        IconsService,
                        DialogContainerService,
                        DialogService,
                        WindowService,
                        WindowContainerService,
                        CalendarDOMService,
                        CenturyViewService,
                        DecadeViewService,
                        MonthViewService,
                        YearViewService,
                        NavigationService
                    ]
                }]
        }] });
