/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Represents the options for the `filterable` setting of the Grid.
 *
 * The available values are:
 * * `row`&mdash;Displays a filter row in Grid. [See example](slug:filter_row).
 * * `menu`&mdash;Displays a filter menu in Grid. [See example](slug:filter_menu).
 * * `menu, row`&mdash;Displays filter menu with filter row.
 *
 * @example
 * ```html
 * <kendo-grid filterable="menu, row"></kendo-grid>
 * ```
 */
export type FilterableSettings = boolean | 'row' | 'menu' | 'menu, row';
/**
 * @hidden
 */
export declare const isFilterable: (settings: FilterableSettings) => boolean;
/**
 * @hidden
 */
export declare const hasFilterMenu: (settings: FilterableSettings) => boolean;
/**
 * @hidden
 */
export declare const hasFilterRow: (settings: FilterableSettings) => boolean;
