/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NavigationService } from './../../navigation/navigation.service';
import { ChangeDetectorRef, ElementRef, OnDestroy, Renderer2, TemplateRef } from '@angular/core';
import { FilterService } from "../filter.service";
import { CompositeFilterDescriptor } from "@progress/kendo-data-query";
import { ColumnComponent } from '../../columns/column.component';
import { SinglePopupService } from '../../common/single-popup.service';
import { PopupRef } from '@progress/kendo-angular-popup';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { ContextService } from '../../common/provider.service';
import { IdService } from '../../common/id.service';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare class FilterMenuComponent implements OnDestroy {
    protected filterService: FilterService;
    protected popupService: SinglePopupService;
    protected ctx: ContextService;
    protected navigationService: NavigationService;
    protected renderer: Renderer2;
    protected cdr: ChangeDetectorRef;
    protected idService: IdService;
    filterIcon: SVGIcon;
    /**
     * The column with which the filter is associated.
     * @type {ColumnComponent}
     */
    column: ColumnComponent;
    /**
     * The current root filter.
     * @type {CompositeFilterDescriptor}
     */
    filter: CompositeFilterDescriptor;
    anchor: ElementRef;
    template: TemplateRef<any>;
    tabIndex: string;
    popupRef: PopupRef;
    private popupSubs;
    constructor(filterService: FilterService, popupService: SinglePopupService, ctx: ContextService, navigationService: NavigationService, renderer: Renderer2, cdr: ChangeDetectorRef, idService: IdService);
    ngOnDestroy(): void;
    get hasFilters(): boolean;
    /**
     * @hidden
     */
    get filterLabel(): string;
    /**
     * @hidden
     */
    get isNavigable(): boolean;
    toggle(anchor: any, template: any): boolean;
    close(): void;
    private updateAria;
    private cleanUp;
    static ɵfac: i0.ɵɵFactoryDeclaration<FilterMenuComponent, [null, null, null, null, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<FilterMenuComponent, "kendo-grid-filter-menu", never, { "column": { "alias": "column"; "required": false; }; "filter": { "alias": "filter"; "required": false; }; "tabIndex": { "alias": "tabIndex"; "required": false; }; }, {}, never, never, true, never>;
}
