/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Represents the default format in which the [kendoGridExpandGroupBy]({% slug api_grid_expandgroupdirective %})
 * directive persists the expanded group keys ([see example]({% slug groups_expanded_state_grid %}#toc-built-in-directive)).
 *
 * Determining whether a group is expanded or collapsed is done by comparing all of the following field values.
 */
export interface GroupKey {
    /**
     * Represents the `field` property value of the current group item.
     */
    field: string;
    /**
     * Represents the `value` property value of the current group item.
     */
    value: any;
    /**
     * An array of `{ field: string, value: any }` items indicating all parent groups of the current one,
     * staring from the direct parent group all the way to the root level one. [See example](slug:groups_expanded_state_grid#toc-default-configuration).
     *
     */
    parentGroupKeys?: Array<{
        field: string;
        value: any;
    }>;
}
