/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PDFService } from './pdf.service';
import { ToolBarButtonComponent } from '@progress/kendo-angular-toolbar';
import * as i0 from "@angular/core";
/**
 * Represents the `export-to-PDF` toolbar tool of the Grid.
 * You can apply this directive to any `kendo-toolbar-button` element inside a
 * ToolbarComponent used in the Grid.
 *
 * When the user clicks the toolbar button that is associated with the directive, the
 * [pdfExport]({% slug api_grid_gridcomponent %}#toc-pdfexport) event
 * fires ([see example]({% slug pdfexport_grid %})).
 *
 * @example
 * ```html-no-run
 * <kendo-grid>
 *      <kendo-toolbar>
 *         <kendo-toolbar-button text="PDF Export" kendoGridPDFTool></kendo-toolbar-button>
 *      </kendo-toolbar>
 *      <kendo-grid-pdf fileName="Grid.pdf">
 *      </kendo-grid-pdf>
 * </kendo-grid>
 * ```
 */
export declare class PDFCommandToolbarDirective {
    private pdfService;
    private host;
    private clickSub;
    constructor(pdfService: PDFService, host: ToolBarButtonComponent);
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * @hidden
     */
    onClick(e: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<PDFCommandToolbarDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<PDFCommandToolbarDirective, "[kendoGridPDFTool]", never, {}, {}, never, never, true, never>;
}
