/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter, OnDestroy, OnChanges, SimpleChanges } from '@angular/core';
import { GridComponent } from '../grid.component';
import { Subscription } from 'rxjs';
import { RowArgs } from './common/row-args';
import * as i0 from "@angular/core";
/**
 * A directive which controls the expanded state of the master detail rows. ([see example](slug:master_detail_expanded_state_grid#toc-built-in-directive))
 */
export declare class ExpandDetailsDirective implements OnChanges, OnDestroy {
    protected grid: GridComponent;
    /**
     * Fires when the expandedDetailKeys are changed.
     */
    expandedDetailKeysChange: EventEmitter<any[]>;
    /**
     * Defines the item key that will be stored in the `expandedDetailKeys` collection ([see example]({% slug master_detail_expanded_state_grid %}#toc-built-in-directive)).
     */
    get expandDetailsKey(): string | ((dataItem: any) => any);
    set expandDetailsKey(key: string | ((dataItem: any) => any));
    /**
     *
     * @hidden
     * A deprecated alias for setting the `expandDetailsKey` property.
     */
    get expandDetailBy(): string | ((dataItem: any) => any);
    set expandDetailBy(key: string | ((dataItem: any) => any));
    /**
     * Defines the collection that will store the expanded keys.
     */
    expandedDetailKeys: any[];
    /**
     * Specifies if the items should be initially expanded.
     * When set to `true` items added to the `expandedDetailKeys` collection will be collapsed, and items that are not present in it will be expanded.
     *
     * @default false
     */
    initiallyExpanded: boolean;
    protected expandedState: Set<any>;
    protected lastExpandedState: any[];
    protected _expandBy: any;
    protected subscriptions: Subscription;
    constructor(grid: GridComponent);
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    protected get keyGetter(): any;
    /**
     * @hidden
     */
    isExpanded(args: RowArgs): boolean;
    private toggleState;
    private notifyChange;
    static ɵfac: i0.ɵɵFactoryDeclaration<ExpandDetailsDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ExpandDetailsDirective, "[kendoGridExpandDetailsBy]", ["kendoGridExpandDetailsBy"], { "expandDetailsKey": { "alias": "kendoGridExpandDetailsBy"; "required": false; }; "expandDetailBy": { "alias": "expandDetailBy"; "required": false; }; "expandedDetailKeys": { "alias": "expandedDetailKeys"; "required": false; }; "initiallyExpanded": { "alias": "initiallyExpanded"; "required": false; }; }, { "expandedDetailKeysChange": "expandedDetailKeysChange"; }, never, never, true, never>;
}
